@@ -1,8 +1,8 @@
 ##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.105_02/lib/Perl/Critic/Policy/Variables/ProhibitPunctuationVars.pm $
-#     $Date: 2010-01-23 21:02:32 -0800 (Sat, 23 Jan 2010) $
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.105_03/lib/Perl/Critic/Policy/Variables/ProhibitPunctuationVars.pm $
+#     $Date: 2010-03-21 18:17:38 -0700 (Sun, 21 Mar 2010) $
 #   $Author: thaljef $
-# $Revision: 3762 $
+# $Revision: 3794 $
 ##############################################################################
 
 package Perl::Critic::Policy::Variables::ProhibitPunctuationVars;
@@ -21,7 +21,7 @@ use Perl::Critic::Utils qw<
 
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.105_02';
+our $VERSION = '1.105_03';
 
 #-----------------------------------------------------------------------------
 
@@ -136,7 +136,28 @@ sub _violates_magic {
 sub _violates_string {
     my ( $self, $elem, undef ) = @_;
 
-    my %matches = _strings_helper( $self, $elem->content() );
+    # RT #55604: Variables::ProhibitPunctuationVars gives false-positive on
+    # qr// regexp's ending in '$'
+    # We want to analyze the content of the string in the dictionary sense of
+    # the word 'content'. We can not simply use the PPI content() method to
+    # get this, because content() includes the delimiters.
+    my $string;
+    if ( $elem->can( 'string' ) ) {
+        # If we have a string() method (currently only the PPI::Token::Quote
+        # classes) use it to extract the content of the string.
+        $string = $elem->string();
+    } else {
+        # Lacking string(), we fake it under the assumption that the content
+        # of our element represents one of the 'normal' Perl strings, with a
+        # single-character delimiter, possibly preceded by an operator like
+        # 'qx' or 'qr'. If there is a leading operator, spaces may appear
+        # after it.
+        $string = $elem->content();
+        $string =~ s/ \A \w* \s* . //smx;
+        chop $string;
+    }
+
+    my %matches = _strings_helper( $self, $string );
     if (%matches) {
         my $DESC = qq<$DESC in interpolated string>;
         return $self->violation( $DESC, $EXPL, $elem );
