@@ -1,8 +1,8 @@
 ##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.105_02/lib/Perl/Critic/Utils/PPI.pm $
-#     $Date: 2010-01-23 21:02:32 -0800 (Sat, 23 Jan 2010) $
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.105_03/lib/Perl/Critic/Utils/PPI.pm $
+#     $Date: 2010-03-21 18:17:38 -0700 (Sun, 21 Mar 2010) $
 #   $Author: thaljef $
-# $Revision: 3762 $
+# $Revision: 3794 $
 ##############################################################################
 
 package Perl::Critic::Utils::PPI;
@@ -17,7 +17,7 @@ use Scalar::Util qw< blessed readonly >;
 
 use base 'Exporter';
 
-our $VERSION = '1.105_02';
+our $VERSION = '1.105_03';
 
 #-----------------------------------------------------------------------------
 
@@ -164,7 +164,7 @@ sub get_constant_name_element_from_declaring_statement {
 
     warnings::warnif(
         'deprecated',
-        'Perl::Critic::Utils::PPI::get_constant_name_element_from_declaring_statement() is deprecated. Use Perl::Critic::PPIx::Utilities::Statement::get_constant_name_elements_from_declaring_statement() instead.',
+        'Perl::Critic::Utils::PPI::get_constant_name_element_from_declaring_statement() is deprecated. Use PPIx::Utilities::Statement::get_constant_name_elements_from_declaring_statement() instead.',
     );
 
     return if not $element;
@@ -333,7 +333,7 @@ Is the parameter a subroutine or inside one?
 =item C<get_constant_name_element_from_declaring_statement($statement)>
 
 B<This subroutine is deprecated.> You should use
-L<Perl::Critic::PPIx::Utilities::Statement/get_constant_name_elements_from_declaring_statement()>
+L<PPIx::Utilities::Statement/get_constant_name_elements_from_declaring_statement()>
 instead.
 
 Given a L<PPI::Statement|PPI::Statement>, if the statement is a C<use
@@ -404,7 +404,7 @@ Elliot Shank <perl@galumph.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2010 Elliot Shank.  All rights reserved.
+Copyright (c) 2007-2010 Elliot Shank.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
